<?php

namespace Drupal\course_migrate\Plugin\migrate\source;

use Drupal\migrate_drupal\Plugin\migrate\source\d7\FieldableEntity;

/**
 * Drupal 7 course enrollment source from database.
 *
 * @MigrateSource(
 *   id = "d7_course_enrollment",
 *   core = {7},
 *   source_module = "course",
 *   destination_module = "course"
 * )
 */
class CourseEnrollment extends FieldableEntity {

  /**
   * {@inheritdoc}
   */
  public function query() {
    $query = $this->select('course_enrollment', 'ce');
    $query->join('course_report', 'cr', 'cr.nid = ce.nid and cr.uid = ce.uid');

    $query->fields('ce');
    $query->fields('cr');

    return $query;
  }

  /**
   * {@inheritdoc}
   */
  public function fields() {
    $fields = [
      'eid' => 'Enrollment ID',
      'uid' => 'User ID',
      'nid' => 'Node ID of course',
      'type' => 'Enrollment type',
      'created' => 'Created date',
      'updated' => 'Updated date',
      'timestamp' => 'Started date',
      'enroll_end' => 'End date',
      'status' => 'End date',
      'data' => 'Serialized data',
      'date_completed' => 'Date completed',
      'coid' => 'Current course object',
      'complete' => 'Complete',
      'grade_result' => 'Grade result',
      'section_name' => 'Section name',
      'enrollmenttype' => 'Source',
    ];
    return $fields;
  }

  /**
   * {@inheritdoc}
   */
  public function getIds() {
    $ids = [];
    $ids['eid']['type'] = 'integer';
    return $ids;
  }

}
